require 'spec_helper'
describe Mail2cb::EmailHandler do

  describe "without environment setup" do
    it "should require REDIS_URL env variable" do
      expect {Mail2cb::EmailWatcher.new}.to raise_error(RuntimeError, "REDIS_URL environment variable is required (eg redis://localhost:6739)")
    end
    it "should require MYSQL_HOST env variable" do
      ENV["REDIS_URL"] = "x"
      expect {Mail2cb::EmailWatcher.new}.to raise_error(RuntimeError, "MYSQL_HOST environment variable is required")
    end
    it "should require MYSQL_DATABASE env variable" do
      ENV["REDIS_URL"] = "x"
      ENV["MYSQL_HOST"] = "x"
      expect {Mail2cb::EmailWatcher.new}.to raise_error(RuntimeError, "MYSQL_DATABASE environment variable is required")
    end
    it "should require MYSQL_USERNAME env variable" do
      ENV["REDIS_URL"] = "x"
      ENV["MYSQL_HOST"] = "x"
      ENV["MYSQL_DATABASE"] = "x"
      expect {Mail2cb::EmailWatcher.new}.to raise_error(RuntimeError, "MYSQL_USERNAME environment variable is required")
    end
    it "should require MYSQL_PASSWORD env variable" do
      ENV["REDIS_URL"] = "x"
      ENV["MYSQL_HOST"] = "x"
      ENV["MYSQL_DATABASE"] = "x"
      ENV["MYSQL_USERNAME"] = "x"
      expect {Mail2cb::EmailWatcher.new}.to raise_error(RuntimeError, "MYSQL_PASSWORD environment variable is required")
    end
  end

  describe "with environment setup" do
    before(:each) do
      setup_env
    end

    it "creates a new mailerdaemon"
    it "starts the daemon"
    it "extracts configuration from mysql"
    it "formats mailbox hash correctly"
    it "calls reload on mail daemon with updated configuration"
    describe "on incoming messages" do
      it "handles incoming messages with correct method"
      it "calls email handler class"
      it "calls sanitize"
      it "calls clean_replies"
      it "calls queue"
    end

    describe "message counts" do
      it "increments message count on mailbox"
      it "updates the last delivered at on mailbox"
      context "with FAYE_HOST" do
        it "publishes to faye"
      end
      context "without FAYE_HOST" do
        it "does not publish to faye"
      end
    end
  end
end
