require 'spec_helper'
describe Mail2cb::Encryption do
  before(:each) do
    ENV.delete("CASEBLOCKS_ENCRYPTION_KEY")
    ENV.delete("CASEBLOCKS_ENCRYPTION_IV")
  end

  it "initializes with default encryption key and vector" do
    enc = Mail2cb::Encryption.new
    expect(enc.instance_variable_get(:@key)).to eq "YLX0IBT+OXaO4mP2bVYqzMPbrrss8eUcX1XtgLxlVH8="
    expect(enc.instance_variable_get(:@iv)).to eq "vvSVfoWvZQ3T/DfjsjO/9w=="
  end
  it "initializes with custom encryption key and vector" do
    ENV["CASEBLOCKS_ENCRYPTION_KEY"] = "abc"
    ENV["CASEBLOCKS_ENCRYPTION_IV"] = "def"
    enc = Mail2cb::Encryption.new
    expect(enc.instance_variable_get(:@key)).to eq "abc"
    expect(enc.instance_variable_get(:@iv)).to eq "def"
  end
  context "with same keys" do
    before(:each) do
      @enc = Mail2cb::Encryption.new
    end
    it "encrypts successfully" do
      expect(@enc.encrypt("i am secret")).to eq "GljJGgTgiVhWM39qw+qHnw=="
    end
    it "decrypts successfully" do
      expect(@enc.decrypt("GljJGgTgiVhWM39qw+qHnw==")).to eq "i am secret"
    end
  end
  context "without different keys" do
    before(:each) do
      @enc_valid = Mail2cb::Encryption.new
      ENV["CASEBLOCKS_ENCRYPTION_KEY"] = "abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz"
      ENV["CASEBLOCKS_ENCRYPTION_IV"] = "abcdefghijklmnopqrstuvwxyz"
      @enc_invalid = Mail2cb::Encryption.new
    end
    it "does not encrypt successfully" do
      valid_encryption = @enc_valid.encrypt("i am another secret")
      expect(@enc_invalid.encrypt("i am another secret")).to_not eq valid_encryption
    end
    it "does not decrypt successfully" do
      valid_encryption = @enc_valid.encrypt("i am another secret")
      expect{@enc_invalid.decrypt(valid_encryption)}.to raise_error(OpenSSL::Cipher::CipherError)
    end
  end
end
