require 'spec_helper'
describe Mail2cb::MessageIdHandler do

  before(:each) do
    @message_id_in_body = Mail.new(sample_mail("reply_message_id_in_body"))
  end

  describe "email with message_id in body and references" do
    it "instantiates with email param" do
      expect(Mail2cb::MessageIdHandler.new(@message_id_in_body)).to be_instance_of Mail2cb::MessageIdHandler
    end

    it "gets message_id from headers" do
      message_id = "conversation.570fb63381e9a82815000006.5714fa5b81e9a84fab000001@mail.caseblocks.com"
      expect(Mail2cb::MessageIdHandler.new(@message_id_in_body).from_headers).to eq(message_id)
    end
    it "does not get message_id from subject" do
      message_id = "conversation.570fb63381e9a82815000006.5714fa5b81e9a84fab000001@mail.caseblocks.com"
      expect(Mail2cb::MessageIdHandler.new(@message_id_in_body).from_subject).to be_falsey
    end
    it "gets message_id from body" do
      message_id = "conversation.570fb63381e9a82815000006.5714fa5b81e9a84fab000001@mail.caseblocks.com"
      expect(Mail2cb::MessageIdHandler.new(@message_id_in_body).from_body).to eq(message_id)
    end
    it "returns correct message_id" do
      message_id = "conversation.570fb63381e9a82815000006.5714fa5b81e9a84fab000001@mail.caseblocks.com"
      expect(Mail2cb::MessageIdHandler.new(@message_id_in_body).message_id).to eq(message_id)
    end
    it "returns correct message_id_hash" do
      message_id_hash = {"conversation_id" => '570fb63381e9a82815000006'}
      expect(Mail2cb::MessageIdHandler.new(@message_id_in_body).hash).to eq(message_id_hash)
    end
  end

end
